@@ -20,7 +20,7 @@
 #  respective owners and no grant or license is provided thereof.
 
 package PDL::IO::Touchstone;
-$VERSION = 1.002;
+$VERSION = 1.003;
 
 use 5.010;
 use strict;
@@ -830,7 +830,7 @@ this module's scope.  Consult the L</"SEE ALSO"> section for more about MDFs and
 is the number of frequencies.
 
 =item * The value of C<$z0> in the conversion functions may be complex-valued and
-is represente as either:
+is represented as either:
 
 =over 4
 
